<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.insightengine.online
 * @since             1.0.1
 * @package           Aiengb
 *
 * @wordpress-plugin
 * Plugin Name:       AI Engine en-GB
 * Plugin URI:        https://www.insightengine.online
 * Description:       Translates AI Engine outputs from American English (en-US) to British English (en-GB).
 * Version:           1.0.1
 * Author:            Kevin K. @ Insight Engine
 * Author URI:        https://www.insightengine.online/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       aiengb
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'AIENGB_VERSION', '1.0.1' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-aiengb-activator.php
 */
function activate_aiengb() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-aiengb-activator.php';
	Aiengb_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-aiengb-deactivator.php
 */
function deactivate_aiengb() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-aiengb-deactivator.php';
	Aiengb_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_aiengb' );
register_deactivation_hook( __FILE__, 'deactivate_aiengb' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-aiengb.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_aiengb() {

	$plugin = new Aiengb();
	$plugin->run();

}
run_aiengb();
